@@ -1,46 +1,58 @@
 #[derive(Debug, PartialEq)]
 /// Errors for token operations.
-pub enum Errors {
+pub enum Error {
     /// Error for a token with an invalid format.
-    TokenFormatError,
+    TokenFormat,
     /// Error for a failed Base64 (URL-safe without padding) decoding.
-    Base64DecodingError,
+    Base64Decoding,
     /// Error for a failed token validation.
-    TokenValidationError,
+    TokenValidation,
     /// Error for an invalid key.
-    KeyError,
+    Key,
     /// Error for a failed encryption operation.
-    EncryptError,
+    Encryption,
     /// Error for a failed attempt to generate bytes using a CSPRNG.
-    CsprngError,
+    Csprng,
     /// Error for a conversion that would be lossy.
-    LossyConversionError,
+    LossyConversion,
     /// Error for attempting to create a token with an empty payload.
-    EmptyPayloadError,
+    EmptyPayload,
     /// Error for attempting to create an invalid claim.
-    InvalidClaimError,
+    InvalidClaim,
     /// Claim validation error. See [`crate::claims::ClaimsValidationRules::validate_claims`].
-    ClaimValidationError,
+    ClaimValidation,
     /// Error for attempting to parse a Claim but found invalid UTF-8 sequence.
     ClaimInvalidUtf8,
     /// Error for attempting to parse a Claim but found invalid JSON sequence.
     ClaimInvalidJson,
+    /// Error during (de)serialization of PASERK types.
+    PaserkParsing,
 }
 
-impl From<ct_codecs::Error> for Errors {
+#[cfg(feature = "std")]
+impl std::error::Error for Error {}
+
+#[cfg(feature = "std")]
+impl std::fmt::Display for Error {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.write_fmt(format_args!("{:?}", self))
+    }
+}
+
+impl From<ct_codecs::Error> for Error {
     fn from(_: ct_codecs::Error) -> Self {
-        Errors::Base64DecodingError
+        Error::Base64Decoding
     }
 }
 
-impl From<getrandom::Error> for Errors {
+impl From<getrandom::Error> for Error {
     fn from(_: getrandom::Error) -> Self {
-        Errors::CsprngError
+        Error::Csprng
     }
 }
 
-impl From<core::num::TryFromIntError> for Errors {
+impl From<core::num::TryFromIntError> for Error {
     fn from(_: core::num::TryFromIntError) -> Self {
-        Errors::LossyConversionError
+        Error::LossyConversion
     }
 }
