@@ -3,8 +3,8 @@ use alloc::vec::Vec;
 use core::convert::TryFrom;
 
 use crate::common::{decode_b64, encode_b64, validate_format_footer};
-use crate::errors::Errors;
-use crate::keys::{AsymmetricPublicKey, AsymmetricSecretKey, SymmetricKey, Version};
+use crate::errors::Error;
+use crate::keys::{AsymmetricPublicKey, AsymmetricSecretKey, SymmetricKey, V2};
 use crate::pae;
 
 /// PASETO v2 public tokens.
@@ -16,21 +16,18 @@ impl PublicToken {
 
     /// Create a public token.
     pub fn sign(
-        secret_key: &AsymmetricSecretKey,
-        public_key: &AsymmetricPublicKey,
+        secret_key: &AsymmetricSecretKey<V2>,
+        public_key: &AsymmetricPublicKey<V2>,
         message: &[u8],
         footer: Option<&[u8]>,
-    ) -> Result<String, Errors> {
+    ) -> Result<String, Error> {
         use ed25519_dalek::Keypair;
         use ed25519_dalek::PublicKey;
         use ed25519_dalek::SecretKey;
         use ed25519_dalek::Signer;
 
-        if secret_key.version != Version::V2 || public_key.version != Version::V2 {
-            return Err(Errors::KeyError);
-        }
         if message.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let secret = SecretKey::from_bytes(secret_key.as_bytes());
@@ -41,7 +38,7 @@ impl PublicToken {
                 secret: sk,
                 public: pk,
             },
-            _ => return Err(Errors::KeyError),
+            _ => return Err(Error::Key),
         };
 
         let f = footer.unwrap_or(&[]);
@@ -62,18 +59,15 @@ impl PublicToken {
 
     /// Verify a public token.
     pub fn verify(
-        public_key: &AsymmetricPublicKey,
+        public_key: &AsymmetricPublicKey<V2>,
         token: &str,
         footer: Option<&[u8]>,
-    ) -> Result<(), Errors> {
+    ) -> Result<(), Error> {
         use ed25519_dalek::PublicKey;
         use ed25519_dalek::Signature;
 
-        if public_key.version != Version::V2 {
-            return Err(Errors::KeyError);
-        }
         if token.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let f = footer.unwrap_or(&[]);
@@ -81,7 +75,7 @@ impl PublicToken {
         let parts_split = validate_format_footer(Self::HEADER, token, f)?;
         let sm = decode_b64(parts_split[2])?;
         if sm.len() < ed25519_dalek::SIGNATURE_LENGTH {
-            return Err(Errors::TokenFormatError);
+            return Err(Error::TokenFormat);
         }
 
         let m = sm[..(sm.len() - ed25519_dalek::SIGNATURE_LENGTH)].as_ref();
@@ -90,20 +84,20 @@ impl PublicToken {
         let m2 = pae::pae(&[Self::HEADER.as_bytes(), m, f])?;
         let pk: PublicKey = match PublicKey::from_bytes(public_key.as_bytes()) {
             Ok(val) => val,
-            Err(_) => return Err(Errors::KeyError),
+            Err(_) => return Err(Error::Key),
         };
 
         debug_assert!(s.len() == ed25519_dalek::SIGNATURE_LENGTH);
         // If the below fails, it is an invalid signature.
         let sig = match Signature::try_from(s) {
             Ok(val) => val,
-            Err(_) => return Err(Errors::TokenValidationError),
+            Err(_) => return Err(Error::TokenValidation),
         };
 
         if pk.verify_strict(m2.as_ref(), &sig).is_ok() {
             Ok(())
         } else {
-            Err(Errors::TokenValidationError)
+            Err(Error::TokenValidation)
         }
     }
 }
@@ -118,11 +112,11 @@ impl LocalToken {
     /// Encrypt and authenticate a message using nonce_key_bytes to derive a nonce
     /// using BLAKE2b.
     pub(crate) fn encrypt_with_derived_nonce(
-        secret_key: &SymmetricKey,
+        secret_key: &SymmetricKey<V2>,
         nonce_key_bytes: &[u8],
         message: &[u8],
         footer: Option<&[u8]>,
-    ) -> Result<String, Errors> {
+    ) -> Result<String, Error> {
         use orion::hazardous::aead::xchacha20poly1305::*;
         use orion::hazardous::hash::blake2b;
         use orion::hazardous::mac::poly1305::POLY1305_OUTSIZE;
@@ -142,7 +136,7 @@ impl LocalToken {
         let mut out = vec![0u8; message.len() + POLY1305_OUTSIZE + nonce.len()];
         let sk = match SecretKey::from_slice(secret_key.as_bytes()) {
             Ok(val) => val,
-            Err(orion::errors::UnknownCryptoError) => return Err(Errors::KeyError),
+            Err(orion::errors::UnknownCryptoError) => return Err(Error::Key),
         };
 
         match seal(
@@ -153,7 +147,7 @@ impl LocalToken {
             &mut out[nonce.len()..],
         ) {
             Ok(()) => (),
-            Err(orion::errors::UnknownCryptoError) => return Err(Errors::EncryptError),
+            Err(orion::errors::UnknownCryptoError) => return Err(Error::Encryption),
         }
 
         out[..nonce.len()].copy_from_slice(nonce.as_ref());
@@ -168,17 +162,14 @@ impl LocalToken {
 
     /// Create a local token.
     pub fn encrypt(
-        secret_key: &SymmetricKey,
+        secret_key: &SymmetricKey<V2>,
         message: &[u8],
         footer: Option<&[u8]>,
-    ) -> Result<String, Errors> {
+    ) -> Result<String, Error> {
         use orion::hazardous::stream::xchacha20::XCHACHA_NONCESIZE;
 
-        if secret_key.version != Version::V2 {
-            return Err(Errors::KeyError);
-        }
         if message.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let mut rng_bytes = [0u8; XCHACHA_NONCESIZE];
@@ -189,26 +180,23 @@ impl LocalToken {
 
     /// Verify and decrypt a local token.
     pub fn decrypt(
-        secret_key: &SymmetricKey,
+        secret_key: &SymmetricKey<V2>,
         token: &str,
         footer: Option<&[u8]>,
-    ) -> Result<Vec<u8>, Errors> {
+    ) -> Result<Vec<u8>, Error> {
         use orion::hazardous::aead::xchacha20poly1305::*;
         use orion::hazardous::mac::poly1305::POLY1305_OUTSIZE;
         use orion::hazardous::stream::xchacha20::XCHACHA_NONCESIZE;
 
-        if secret_key.version != Version::V2 {
-            return Err(Errors::KeyError);
-        }
         if token.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let f = footer.unwrap_or(&[]);
         let parts_split = validate_format_footer(Self::HEADER, token, f)?;
         let nc = decode_b64(parts_split[2])?;
         if nc.len() < (XCHACHA_NONCESIZE + POLY1305_OUTSIZE) {
-            return Err(Errors::TokenFormatError);
+            return Err(Error::TokenFormat);
         }
         let n = nc[..XCHACHA_NONCESIZE].as_ref();
         let c = nc[n.len()..].as_ref();
@@ -218,7 +206,7 @@ impl LocalToken {
 
         let sk = match SecretKey::from_slice(secret_key.as_bytes()) {
             Ok(val) => val,
-            Err(orion::errors::UnknownCryptoError) => return Err(Errors::KeyError),
+            Err(orion::errors::UnknownCryptoError) => return Err(Error::Key),
         };
 
         match open(
@@ -229,12 +217,13 @@ impl LocalToken {
             &mut out,
         ) {
             Ok(()) => Ok(out),
-            Err(orion::errors::UnknownCryptoError) => Err(Errors::TokenValidationError),
+            Err(orion::errors::UnknownCryptoError) => Err(Error::TokenValidation),
         }
     }
 }
 
 #[cfg(test)]
+#[cfg(feature = "std")]
 mod test_vectors {
 
     use hex;
@@ -245,17 +234,13 @@ mod test_vectors {
 
     use crate::claims::Claims;
     use crate::common::tests::*;
-    use crate::keys::Version;
 
     fn test_local(test: &PasetoTest) {
         debug_assert!(test.nonce.is_some());
         debug_assert!(test.key.is_some());
 
-        let sk = SymmetricKey::from(
-            &hex::decode(test.key.as_ref().unwrap()).unwrap(),
-            Version::V2,
-        )
-        .unwrap();
+        let sk =
+            SymmetricKey::<V2>::from(&hex::decode(test.key.as_ref().unwrap()).unwrap()).unwrap();
 
         let nonce = hex::decode(test.nonce.as_ref().unwrap()).unwrap();
         let footer = test.footer.as_bytes();
@@ -292,14 +277,12 @@ mod test_vectors {
         debug_assert!(test.public_key.is_some());
         debug_assert!(test.secret_key.is_some());
 
-        let sk = AsymmetricSecretKey::from(
+        let sk = AsymmetricSecretKey::<V2>::from(
             &hex::decode(test.secret_key.as_ref().unwrap()).unwrap()[..32],
-            Version::V2,
         )
         .unwrap();
-        let pk = AsymmetricPublicKey::from(
+        let pk = AsymmetricPublicKey::<V2>::from(
             &hex::decode(test.public_key.as_ref().unwrap()).unwrap(),
-            Version::V2,
         )
         .unwrap();
         let footer = test.footer.as_bytes();
@@ -344,7 +327,6 @@ mod test_vectors {
 
 #[cfg(test)]
 mod tests {
-
     use super::*;
 
     const TEST_SK_BYTES: [u8; 32] = [
@@ -365,7 +347,7 @@ mod tests {
 
     #[test]
     fn test_roundtrip_local() {
-        let sk = SymmetricKey::gen(Version::V2).unwrap();
+        let sk = SymmetricKey::<V2>::gen().unwrap();
 
         let token = LocalToken::encrypt(&sk, MESSAGE.as_bytes(), None).unwrap();
         let payload = LocalToken::decrypt(&sk, &token, None).unwrap();
@@ -375,8 +357,8 @@ mod tests {
 
     #[test]
     fn test_roundtrip_public() {
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
+        let test_sk = AsymmetricSecretKey::<V2>::from(&TEST_SK_BYTES).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
 
         let token = PublicToken::sign(&test_sk, &test_pk, MESSAGE.as_bytes(), None).unwrap();
         assert!(PublicToken::verify(&test_pk, &token, None).is_ok());
@@ -384,9 +366,9 @@ mod tests {
 
     #[test]
     fn footer_none_some_empty_is_same() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
+        let test_sk = AsymmetricSecretKey::<V2>::from(&TEST_SK_BYTES).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
         let message =
             b"{\"data\":\"this is a signed message\",\"exp\":\"2019-01-01T00:00:00+00:00\"}";
         let footer = b"";
@@ -409,57 +391,32 @@ mod tests {
     #[test]
     // NOTE: See https://github.com/paseto-standard/paseto-spec/issues/17
     fn empty_payload() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
+        let test_sk = AsymmetricSecretKey::<V2>::from(&TEST_SK_BYTES).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::sign(&test_sk, &test_pk, b"", None).unwrap_err(),
-            Errors::EmptyPayloadError
+            Error::EmptyPayload
         );
         assert_eq!(
             PublicToken::verify(&test_pk, "", None).unwrap_err(),
-            Errors::EmptyPayloadError
+            Error::EmptyPayload
         );
         assert_eq!(
             LocalToken::encrypt(&test_local_sk, b"", None).unwrap_err(),
-            Errors::EmptyPayloadError
+            Error::EmptyPayload
         );
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, "", None).unwrap_err(),
-            Errors::EmptyPayloadError
-        );
-    }
-
-    #[test]
-    // NOTE: "Algorithm lucidity" from spec.
-    fn wrong_key_version() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-
-        assert_eq!(
-            PublicToken::sign(&test_sk, &test_pk, b"test", None).unwrap_err(),
-            Errors::KeyError
-        );
-        assert_eq!(
-            PublicToken::verify(&test_pk, "test", None).unwrap_err(),
-            Errors::KeyError
-        );
-        assert_eq!(
-            LocalToken::encrypt(&test_local_sk, b"test", None).unwrap_err(),
-            Errors::KeyError
-        );
-        assert_eq!(
-            LocalToken::decrypt(&test_local_sk, "test", None).unwrap_err(),
-            Errors::KeyError
+            Error::EmptyPayload
         );
     }
 
     #[test]
     fn err_on_modified_header() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(
@@ -468,7 +425,7 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -477,7 +434,7 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             PublicToken::verify(
@@ -486,7 +443,7 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -495,14 +452,14 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     fn err_on_modified_purpose() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(
@@ -511,7 +468,7 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -520,7 +477,7 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             PublicToken::verify(
@@ -529,7 +486,7 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -538,15 +495,15 @@ mod tests {
                 Some(FOOTER.as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     // NOTE: Missing but created with one
     fn err_on_missing_payload() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         let mut split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         split_public[2] = "";
@@ -558,19 +515,19 @@ mod tests {
 
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes())).unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &invalid_local, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     fn err_on_extra_after_footer() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         let mut split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         split_public.push(".shouldNotBeHere");
@@ -582,19 +539,19 @@ mod tests {
 
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes())).unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &invalid_local, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     fn err_on_modified_footer() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(
@@ -603,7 +560,7 @@ mod tests {
                 Some(&FOOTER.replace("kid", "mid").as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -612,29 +569,29 @@ mod tests {
                 Some(&FOOTER.replace("kid", "mid").as_bytes())
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_footer_in_token_none_supplied() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(&test_pk, &VALID_PUBLIC_TOKEN, Some(b"")).unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &VALID_LOCAL_TOKEN, Some(b"")).unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_no_footer_in_token_some_supplied() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         let split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         let invalid_public: String = format!(
@@ -648,18 +605,18 @@ mod tests {
 
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes())).unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &invalid_local, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_signature() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
+        let test_pk = AsymmetricPublicKey::<V2>::from(&TEST_PK_BYTES).unwrap();
 
         let mut split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_sig = Vec::from(decode_b64(split_public[2]).unwrap());
@@ -673,13 +630,13 @@ mod tests {
 
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes())).unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_tag() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_tag = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -695,13 +652,13 @@ mod tests {
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &invalid_local, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_ciphertext() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_ct = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -717,13 +674,13 @@ mod tests {
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &invalid_local, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_nonce() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_nonce = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -739,13 +696,13 @@ mod tests {
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &invalid_local, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_invalid_base64() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
+        let test_local_sk = SymmetricKey::<V2>::from(&TEST_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_nonce = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -761,28 +718,28 @@ mod tests {
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &invalid_local, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_invalid_public_secret_key() {
-        let bad_pk = AsymmetricPublicKey::from(&[0u8; 32], Version::V2).unwrap();
+        let bad_pk = AsymmetricPublicKey::<V2>::from(&[0u8; 32]).unwrap();
 
         assert_eq!(
             PublicToken::verify(&bad_pk, VALID_PUBLIC_TOKEN, Some(FOOTER.as_bytes())).unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_invalid_shared_secret_key() {
-        let bad_local_sk = SymmetricKey::from(&[0u8; 32], Version::V2).unwrap();
+        let bad_local_sk = SymmetricKey::<V2>::from(&[0u8; 32]).unwrap();
 
         assert_eq!(
             LocalToken::decrypt(&bad_local_sk, VALID_LOCAL_TOKEN, Some(FOOTER.as_bytes()))
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 }
