@@ -2,8 +2,8 @@ use alloc::string::String;
 use alloc::vec::Vec;
 use core::convert::TryFrom;
 
-use crate::errors::Errors;
-use crate::keys::{AsymmetricPublicKey, AsymmetricSecretKey, SymmetricKey, Version};
+use crate::errors::Error;
+use crate::keys::{AsymmetricPublicKey, AsymmetricSecretKey, SymmetricKey, V4};
 
 use orion::hazardous::hash::blake2b;
 use orion::hazardous::hash::blake2b::Blake2b;
@@ -25,22 +25,19 @@ impl PublicToken {
 
     /// Create a public token.
     pub fn sign(
-        secret_key: &AsymmetricSecretKey,
-        public_key: &AsymmetricPublicKey,
+        secret_key: &AsymmetricSecretKey<V4>,
+        public_key: &AsymmetricPublicKey<V4>,
         message: &[u8],
         footer: Option<&[u8]>,
         implicit_assert: Option<&[u8]>,
-    ) -> Result<String, Errors> {
+    ) -> Result<String, Error> {
         use ed25519_dalek::Keypair;
         use ed25519_dalek::PublicKey;
         use ed25519_dalek::SecretKey;
         use ed25519_dalek::Signer;
 
-        if secret_key.version != Version::V4 || public_key.version != Version::V4 {
-            return Err(Errors::KeyError);
-        }
         if message.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let secret = SecretKey::from_bytes(secret_key.as_bytes());
@@ -51,7 +48,7 @@ impl PublicToken {
                 secret: sk,
                 public: pk,
             },
-            _ => return Err(Errors::KeyError),
+            _ => return Err(Error::Key),
         };
 
         let f = footer.unwrap_or(&[]);
@@ -73,19 +70,16 @@ impl PublicToken {
 
     /// Verify a public token.
     pub fn verify(
-        public_key: &AsymmetricPublicKey,
+        public_key: &AsymmetricPublicKey<V4>,
         token: &str,
         footer: Option<&[u8]>,
         implicit_assert: Option<&[u8]>,
-    ) -> Result<(), Errors> {
+    ) -> Result<(), Error> {
         use ed25519_dalek::PublicKey;
         use ed25519_dalek::Signature;
 
-        if public_key.version != Version::V4 {
-            return Err(Errors::KeyError);
-        }
         if token.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let f = footer.unwrap_or(&[]);
@@ -94,7 +88,7 @@ impl PublicToken {
         let parts_split = validate_format_footer(Self::HEADER, token, f)?;
         let sm = decode_b64(parts_split[2])?;
         if sm.len() < ed25519_dalek::SIGNATURE_LENGTH {
-            return Err(Errors::TokenFormatError);
+            return Err(Error::TokenFormat);
         }
 
         let m = sm[..(sm.len() - ed25519_dalek::SIGNATURE_LENGTH)].as_ref();
@@ -103,20 +97,20 @@ impl PublicToken {
         let m2 = pae::pae(&[Self::HEADER.as_bytes(), m, f, i])?;
         let pk: PublicKey = match PublicKey::from_bytes(public_key.as_bytes()) {
             Ok(val) => val,
-            Err(_) => return Err(Errors::KeyError),
+            Err(_) => return Err(Error::Key),
         };
 
         debug_assert!(s.len() == ed25519_dalek::SIGNATURE_LENGTH);
         // If the below fails, it is an invalid signature.
         let sig = match Signature::try_from(s) {
             Ok(val) => val,
-            Err(_) => return Err(Errors::TokenValidationError),
+            Err(_) => return Err(Error::TokenValidation),
         };
 
         if pk.verify_strict(m2.as_ref(), &sig).is_ok() {
             Ok(())
         } else {
-            Err(Errors::TokenValidationError)
+            Err(Error::TokenValidation)
         }
     }
 }
@@ -144,7 +138,7 @@ impl LocalToken {
     const TAG_LEN: usize = 32;
 
     /// Split the user-provided secret key into keys used for encryption and authentication.
-    fn key_split(sk: &[u8], n: &[u8]) -> Result<(EncKey, EncNonce, AuthKey), Errors> {
+    fn key_split(sk: &[u8], n: &[u8]) -> Result<(EncKey, EncNonce, AuthKey), Error> {
         debug_assert_eq!(n.len(), 32);
         debug_assert_eq!(sk.len(), 32);
 
@@ -172,14 +166,13 @@ impl LocalToken {
 
     /// Encrypt and authenticate a message using nonce directly.
     pub(crate) fn encrypt_with_nonce(
-        secret_key: &SymmetricKey,
+        secret_key: &SymmetricKey<V4>,
         nonce: &[u8],
         message: &[u8],
         footer: Option<&[u8]>,
         implicit_assert: Option<&[u8]>,
-    ) -> Result<String, Errors> {
+    ) -> Result<String, Error> {
         debug_assert_eq!(nonce.len(), 32);
-
         let f = footer.unwrap_or(&[]);
         let i = implicit_assert.unwrap_or(&[]);
 
@@ -187,19 +180,19 @@ impl LocalToken {
 
         let mut ciphertext = vec![0u8; message.len()];
         xchacha20::encrypt(&enc_key, &n2, 0, message, &mut ciphertext)
-            .map_err(|_| Errors::EncryptError)?;
+            .map_err(|_| Error::Encryption)?;
         let pre_auth = pae::pae(&[Self::HEADER.as_bytes(), nonce, ciphertext.as_slice(), f, i])?;
 
         let mut b2_ctx = Blake2b::new(Some(&auth_key), Self::TAG_LEN).unwrap();
         b2_ctx
             .update(pre_auth.as_slice())
-            .map_err(|_| Errors::EncryptError)?;
-        let tag = b2_ctx.finalize().map_err(|_| Errors::EncryptError)?;
+            .map_err(|_| Error::Encryption)?;
+        let tag = b2_ctx.finalize().map_err(|_| Error::Encryption)?;
 
         // nonce and tag lengths are both 32, so obviously safe to op::add
         let concat_len: usize = match (nonce.len() + tag.len()).checked_add(ciphertext.len()) {
             Some(len) => len,
-            None => return Err(Errors::EncryptError),
+            None => return Err(Error::Encryption),
         };
         let mut concat = vec![0u8; concat_len];
         concat[..32].copy_from_slice(nonce);
@@ -217,16 +210,13 @@ impl LocalToken {
 
     /// Create a local token.
     pub fn encrypt(
-        secret_key: &SymmetricKey,
+        secret_key: &SymmetricKey<V4>,
         message: &[u8],
         footer: Option<&[u8]>,
         implicit_assert: Option<&[u8]>,
-    ) -> Result<String, Errors> {
-        if secret_key.version != Version::V4 {
-            return Err(Errors::KeyError);
-        }
+    ) -> Result<String, Error> {
         if message.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let mut n = [0u8; 32];
@@ -238,16 +228,13 @@ impl LocalToken {
     #[allow(clippy::many_single_char_names)] // The single-char names match those in the spec
     /// Verify and decrypt a local token.
     pub fn decrypt(
-        secret_key: &SymmetricKey,
+        secret_key: &SymmetricKey<V4>,
         token: &str,
         footer: Option<&[u8]>,
         implicit_assert: Option<&[u8]>,
-    ) -> Result<Vec<u8>, Errors> {
-        if secret_key.version != Version::V4 {
-            return Err(Errors::KeyError);
-        }
+    ) -> Result<Vec<u8>, Error> {
         if token.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
 
         let f = footer.unwrap_or(&[]);
@@ -256,32 +243,31 @@ impl LocalToken {
 
         let nc = decode_b64(parts_split[2])?;
         if nc.len() < (Self::N_LEN + Self::TAG_LEN) {
-            return Err(Errors::TokenFormatError);
+            return Err(Error::TokenFormat);
         }
         let mut n: [u8; 32] = [0u8; 32];
         n.copy_from_slice(nc[..32].as_ref());
         let c = nc[n.len()..nc.len() - 32].as_ref();
         if c.is_empty() {
-            return Err(Errors::EmptyPayloadError);
+            return Err(Error::EmptyPayload);
         }
         let t = nc[nc.len() - Self::TAG_LEN..].as_ref();
 
         let (enc_key, n2, auth_key) = Self::key_split(secret_key.as_bytes(), &n)?;
 
         let pre_auth = pae::pae(&[Self::HEADER.as_bytes(), n.as_ref(), c, f, i])?;
-        let expected_tag =
-            blake2b::Digest::from_slice(t).map_err(|_| Errors::TokenValidationError)?;
+        let expected_tag = blake2b::Digest::from_slice(t).map_err(|_| Error::TokenValidation)?;
         blake2b::Blake2b::verify(&expected_tag, &auth_key, 32, pre_auth.as_slice())
-            .map_err(|_| Errors::TokenValidationError)?;
+            .map_err(|_| Error::TokenValidation)?;
 
         let mut out = vec![0u8; c.len()];
-        xchacha20::decrypt(&enc_key, &n2, 0, c, &mut out)
-            .map_err(|_| Errors::TokenValidationError)?;
+        xchacha20::decrypt(&enc_key, &n2, 0, c, &mut out).map_err(|_| Error::TokenValidation)?;
         Ok(out)
     }
 }
 
 #[cfg(test)]
+#[cfg(feature = "std")]
 mod test_vectors {
 
     use hex;
@@ -292,17 +278,13 @@ mod test_vectors {
 
     use crate::claims::Claims;
     use crate::common::tests::*;
-    use crate::keys::Version;
 
     fn test_local(test: &PasetoTest) {
         debug_assert!(test.nonce.is_some());
         debug_assert!(test.key.is_some());
 
-        let sk = SymmetricKey::from(
-            &hex::decode(test.key.as_ref().unwrap()).unwrap(),
-            Version::V4,
-        )
-        .unwrap();
+        let sk =
+            SymmetricKey::<V4>::from(&hex::decode(test.key.as_ref().unwrap()).unwrap()).unwrap();
 
         let nonce = hex::decode(test.nonce.as_ref().unwrap()).unwrap();
         let footer = test.footer.as_bytes();
@@ -348,14 +330,12 @@ mod test_vectors {
         debug_assert!(test.public_key.is_some());
         debug_assert!(test.secret_key.is_some());
 
-        let sk = AsymmetricSecretKey::from(
+        let sk = AsymmetricSecretKey::<V4>::from(
             &hex::decode(test.secret_key.as_ref().unwrap()).unwrap()[..32],
-            Version::V4,
         )
         .unwrap();
-        let pk = AsymmetricPublicKey::from(
+        let pk = AsymmetricPublicKey::<V4>::from(
             &hex::decode(test.public_key.as_ref().unwrap()).unwrap(),
-            Version::V4,
         )
         .unwrap();
         let footer = test.footer.as_bytes();
@@ -411,7 +391,7 @@ mod test_vectors {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::keys::{SymmetricKey, Version};
+    use crate::keys::SymmetricKey;
 
     // In version 2 tests, the SK used for public tokens is valid for the local as well.
     // Not the case with version 4.
@@ -438,7 +418,7 @@ mod tests {
 
     #[test]
     fn test_roundtrip_local() {
-        let sk = SymmetricKey::gen(Version::V4).unwrap();
+        let sk = SymmetricKey::<V4>::gen().unwrap();
         let message = b"token payload";
 
         let token = LocalToken::encrypt(&sk, message, None, None).unwrap();
@@ -449,8 +429,8 @@ mod tests {
 
     #[test]
     fn test_roundtrip_public() {
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
+        let test_sk = AsymmetricSecretKey::<V4>::from(&TEST_SK_BYTES).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
 
         let token = PublicToken::sign(&test_sk, &test_pk, MESSAGE.as_bytes(), None, None).unwrap();
         assert!(PublicToken::verify(&test_pk, &token, None, None).is_ok());
@@ -458,9 +438,9 @@ mod tests {
 
     #[test]
     fn footer_none_some_empty_is_same() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_SK_BYTES).unwrap();
+        let test_sk = AsymmetricSecretKey::<V4>::from(&TEST_SK_BYTES).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
         let message =
             b"{\"data\":\"this is a signed message\",\"exp\":\"2019-01-01T00:00:00+00:00\"}";
         let footer = b"";
@@ -483,9 +463,9 @@ mod tests {
 
     #[test]
     fn implicit_none_some_empty_is_same() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_SK_BYTES).unwrap();
+        let test_sk = AsymmetricSecretKey::<V4>::from(&TEST_SK_BYTES).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
         let message =
             b"{\"data\":\"this is a signed message\",\"exp\":\"2019-01-01T00:00:00+00:00\"}";
         let implicit = b"";
@@ -509,13 +489,10 @@ mod tests {
 
     #[test]
     fn fuzztest_bug_one() {
-        let sk1 = SymmetricKey::from(
-            &[
-                141, 225, 124, 245, 68, 230, 197, 175, 179, 197, 127, 83, 207, 183, 85, 164, 230,
-                24, 14, 91, 230, 213, 164, 30, 243, 64, 184, 132, 198, 120, 44, 228,
-            ],
-            Version::V4,
-        )
+        let sk1 = SymmetricKey::<V4>::from(&[
+            141, 225, 124, 245, 68, 230, 197, 175, 179, 197, 127, 83, 207, 183, 85, 164, 230, 24,
+            14, 91, 230, 213, 164, 30, 243, 64, 184, 132, 198, 120, 44, 228,
+        ])
         .unwrap();
 
         let crashing_token =
@@ -526,57 +503,32 @@ mod tests {
     #[test]
     // NOTE: See https://github.com/paseto-standard/paseto-spec/issues/17
     fn empty_payload() {
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V4).unwrap();
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_SK_BYTES).unwrap();
+        let test_sk = AsymmetricSecretKey::<V4>::from(&TEST_SK_BYTES).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::sign(&test_sk, &test_pk, b"", None, None).unwrap_err(),
-            Errors::EmptyPayloadError
+            Error::EmptyPayload
         );
         assert_eq!(
             PublicToken::verify(&test_pk, "", None, None).unwrap_err(),
-            Errors::EmptyPayloadError
+            Error::EmptyPayload
         );
         assert_eq!(
             LocalToken::encrypt(&test_local_sk, b"", None, None).unwrap_err(),
-            Errors::EmptyPayloadError
+            Error::EmptyPayload
         );
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, "", None, None).unwrap_err(),
-            Errors::EmptyPayloadError
-        );
-    }
-
-    #[test]
-    // NOTE: "Algorithm lucidity" from spec.
-    fn wrong_key_version() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V2).unwrap();
-        let test_sk = AsymmetricSecretKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_SK_BYTES, Version::V2).unwrap();
-
-        assert_eq!(
-            PublicToken::sign(&test_sk, &test_pk, b"test", None, None).unwrap_err(),
-            Errors::KeyError
-        );
-        assert_eq!(
-            PublicToken::verify(&test_pk, "test", None, None).unwrap_err(),
-            Errors::KeyError
-        );
-        assert_eq!(
-            LocalToken::encrypt(&test_local_sk, b"test", None, None).unwrap_err(),
-            Errors::KeyError
-        );
-        assert_eq!(
-            LocalToken::decrypt(&test_local_sk, "test", None, None).unwrap_err(),
-            Errors::KeyError
+            Error::EmptyPayload
         );
     }
 
     #[test]
     fn err_on_modified_header() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(
@@ -586,7 +538,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -596,7 +548,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             PublicToken::verify(
@@ -606,7 +558,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -616,14 +568,14 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     fn err_on_modified_purpose() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(
@@ -633,7 +585,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -643,7 +595,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             PublicToken::verify(
@@ -653,7 +605,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -663,15 +615,15 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     // NOTE: Missing but created with one
     fn err_on_missing_payload() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         let mut split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         split_public[2] = "";
@@ -684,7 +636,7 @@ mod tests {
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes()), None)
                 .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -694,14 +646,14 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     fn err_on_extra_after_footer() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         let mut split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         split_public.push(".shouldNotBeHere");
@@ -714,7 +666,7 @@ mod tests {
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes()), None)
                 .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -724,14 +676,14 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenFormatError
+            Error::TokenFormat
         );
     }
 
     #[test]
     fn err_on_modified_footer() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(
@@ -741,7 +693,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -751,14 +703,14 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_wrong_implicit_assert() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
         assert!(
             PublicToken::verify(&test_pk, &VALID_PUBLIC_TOKEN, Some(FOOTER.as_bytes()), None)
                 .is_ok()
@@ -771,7 +723,7 @@ mod tests {
                 Some(b"WRONG IMPLICIT")
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
         assert!(LocalToken::decrypt(
             &test_local_sk,
@@ -788,29 +740,29 @@ mod tests {
                 Some(b"WRONG IMPLICIT")
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_footer_in_token_none_supplied() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         assert_eq!(
             PublicToken::verify(&test_pk, &VALID_PUBLIC_TOKEN, Some(b""), None).unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
         assert_eq!(
             LocalToken::decrypt(&test_local_sk, &VALID_LOCAL_TOKEN, Some(b""), None).unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_no_footer_in_token_some_supplied() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         let split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         let invalid_public: String = format!(
@@ -825,7 +777,7 @@ mod tests {
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes()), None)
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
         assert_eq!(
             LocalToken::decrypt(
@@ -835,13 +787,13 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_signature() {
-        let test_pk = AsymmetricPublicKey::from(&TEST_PK_BYTES, Version::V4).unwrap();
+        let test_pk = AsymmetricPublicKey::<V4>::from(&TEST_PK_BYTES).unwrap();
 
         let mut split_public = VALID_PUBLIC_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_sig = Vec::from(decode_b64(split_public[2]).unwrap());
@@ -856,13 +808,13 @@ mod tests {
         assert_eq!(
             PublicToken::verify(&test_pk, &invalid_public, Some(FOOTER.as_bytes()), None)
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_tag() {
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_tag = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -883,13 +835,13 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_ciphertext() {
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_ct = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -910,13 +862,13 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_modified_nonce() {
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_nonce = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -937,13 +889,13 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_invalid_base64() {
-        let test_local_sk = SymmetricKey::from(&TEST_LOCAL_SK_BYTES, Version::V4).unwrap();
+        let test_local_sk = SymmetricKey::<V4>::from(&TEST_LOCAL_SK_BYTES).unwrap();
 
         let mut split_local = VALID_LOCAL_TOKEN.split('.').collect::<Vec<&str>>();
         let mut bad_nonce = Vec::from(decode_b64(split_local[2]).unwrap());
@@ -964,24 +916,24 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_invalid_public_secret_key() {
-        let bad_pk = AsymmetricPublicKey::from(&[0u8; 32], Version::V4).unwrap();
+        let bad_pk = AsymmetricPublicKey::<V4>::from(&[0u8; 32]).unwrap();
 
         assert_eq!(
             PublicToken::verify(&bad_pk, VALID_PUBLIC_TOKEN, Some(FOOTER.as_bytes()), None)
                 .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 
     #[test]
     fn err_on_invalid_shared_secret_key() {
-        let bad_local_sk = SymmetricKey::from(&[0u8; 32], Version::V4).unwrap();
+        let bad_local_sk = SymmetricKey::<V4>::from(&[0u8; 32]).unwrap();
 
         assert_eq!(
             LocalToken::decrypt(
@@ -991,7 +943,7 @@ mod tests {
                 None
             )
             .unwrap_err(),
-            Errors::TokenValidationError
+            Error::TokenValidation
         );
     }
 }
